Designators

Struct Designators 

struct Designators {
    singular: [&'static str; 10],
    plural: [&'static str; 10],
}
A type that represents the designator choice.

Basically, whether we want verbose, short or compact designators. This in turn permits lookups based on Unit, which makes writing generic code for writing designators a bit nicer and still fast.

Fields

singular: [&'static str; 10]plural: [&'static str; 10]

Implementations

Source

impl Designators

const VERBOSE_SINGULAR: [&'static str; 10]

const VERBOSE_PLURAL: [&'static str; 10]

const SHORT_SINGULAR: [&'static str; 10]

const SHORT_PLURAL: [&'static str; 10]

const COMPACT: [&'static str; 10]

const HUMAN_TIME_SINGULAR: [&'static str; 10]

const HUMAN_TIME_PLURAL: [&'static str; 10]

const fn new(config: Designator) -> &'static Designators

fn designator(&self, unit: impl Into<Unit>, plural: bool) -> &'static str